@@ -72,8 +72,11 @@ class DataBaseWorker:
             self.schema = self.cred["database"]
 
     def __del__(self):
-        self.logger.info("Dispose engine to {}, host:{}".format(self.db, self.cred["host"]))
-        self.engine.dispose()
+        try:
+            self.engine.dispose()
+            self.logger.info("Dispose engine to {}, host:{}".format(self.db, self.cred["host"]))
+        except KeyError:
+            pass
 
     def __check_dialect(self):
         if self.db not in base_converter_params.keys():
@@ -101,14 +104,14 @@ class DataBaseWorker:
             tables = [self.table_name]
         if len(tables) > 0 and self.table_checker:
             try:
-                meta.reflect(only=tables)
+                meta.reflect(only=tables, views=True)
             except sqlalchemy.exc.InvalidRequestError:
                 raise sqlalchemy.exc.InvalidRequestError(
                     "One or more file didn't find in database {}. Critical exception"
                 )
         elif len(tables) > 0 and not self.table_checker:
             try:
-                meta.reflect(only=tables)
+                meta.reflect(only=tables, views=True)
             except sqlalchemy.exc.InvalidRequestError:
                 self.logger.error(
                     "One or more file didn't find in database {}. Load table later".format(
@@ -117,7 +120,7 @@ class DataBaseWorker:
                 )
                 meta = None
         else:
-            meta.reflect()
+            meta.reflect(views=True)
         return meta
 
     @property
@@ -151,6 +154,8 @@ class DataBaseWorker:
             "data_type",
             "character_maximum_length",
             "column_default",
+            "comment",
+            "object_type"
         ]
         self.table_name = table_name
         table_sql = Table(table_name, self.meta)
@@ -159,7 +164,9 @@ class DataBaseWorker:
         types = [get_type_sql_alchemy(c.type) for c in table_sql.columns]
         length = [get_length_type_sql_alchemy(c.type) for c in table_sql.columns]
         default = [get_default_arg_sql_alchemy(c) for c in table_sql.columns]
-        fields = list(zip(columns, types, length, default))
+        comment = [c.comment for c in table_sql.columns]
+        object_type = [c.type for c in table_sql.columns]
+        fields = list(zip(columns, types, length, default, comment, object_type))
         fields = [dict(zip(columns_name, f)) for f in fields]
         return fields
 
