@@ -71,6 +71,10 @@ class FieldsConverter:
                 )
             )
 
+    def __del__(self):
+        self.db_worker_from.__del__()
+        self.db_worker_to.__del__()
+
     @property
     def __str__(self):
         return "FieldsConverter_{}_{}".format(self.from_db, self.to_db)
